@@ -1871,7 +1871,7 @@ iInt2 tryAdvance_Text(int fontId, iRangecc text, int width, const char **endPos)
 }
 
 iInt2 tryAdvanceNoWrap_Text(int fontId, iRangecc text, int width, const char **endPos) {
-    if (width <= 1) {
+    if (width && width <= 1) {
         *endPos = text.start;
         return zero_I2();
     }
@@ -2070,7 +2070,7 @@ iTextMetrics draw_WrapText(iWrapText *d, int fontId, iInt2 pos, int color) {
         const int width = d->mode == word_WrapTextMode
                               ? tryAdvance_Text(fontId, text, d->maxWidth, &endPos).x
                               : tryAdvanceNoWrap_Text(fontId, text, d->maxWidth, &endPos).x;
-        notify_WrapText_(d, endPos, (iTextAttrib){ .colorId = color }, 0, width);
+        notify_WrapText_(d, endPos, (iTextAttrib){ .fgColorId = color }, 0, width);
         drawRange_Text(fontId, pos, color, (iRangecc){ text.start, endPos });
         text.start = endPos;
         pos.y += lineHeight_Text(fontId);
