@@ -1961,7 +1961,8 @@ iBool isAffectedByVisualOffset_Widget(const iWidget *d) {
 }
 
 void setFocus_Widget(iWidget *d) {
-    iWindow *win = get_Window();
+    iWindow *win = d ? window_Widget(d) : get_Window();
+    iAssert(win);
     if (win->focus != d) {
         if (win->focus) {
             iAssert(!contains_PtrSet(win->focus->root->pendingDestruction, win->focus));
@@ -1976,6 +1977,13 @@ void setFocus_Widget(iWidget *d) {
     }
 }
 
+void setKeyboardGrab_Widget(iWidget *d) {
+    iWindow *win = d ? window_Widget(d) : get_Window();
+    iAssert(win);
+    win->focus = d;
+    /* no notifications sent */
+}
+
 iWidget *focus_Widget(void) {
     return get_Window()->focus;
 }
